@@ -9,7 +9,7 @@ module Listen
   module Adapter
     OPTIMIZED_ADAPTERS = [Darwin, Linux, BSD, Windows]
     POLLING_FALLBACK_MESSAGE = 'Listen will be polling for changes.'\
-      'Learn more at https://github.com/guard/listen#polling-fallback.'
+      'Learn more at https://github.com/guard/listen#listen-adapters.'
 
     def self.select(options = {})
       _log :debug, 'Adapter: considering TCP ...'
@@ -22,7 +22,8 @@ module Listen
       _warn_polling_fallback(options)
       Polling
     rescue
-      _log :warn, "Adapter: failed: #{$!.inspect}:#{$@.join("\n")}"
+      _log :warn, format('Adapter: failed: %s:%s', $ERROR_POSITION.inspect,
+                         $ERROR_POSITION * "\n")
       raise
     end
 
@@ -38,7 +39,7 @@ module Listen
     end
 
     def self._log(type, message)
-      Celluloid.logger.send(type, message)
+      Celluloid::Logger.send(type, message)
     end
   end
 end
